@@ -9,6 +9,7 @@ import os
 import site
 import sys
 import typing
+from functools import cached_property
 from pathlib import Path
 from sysconfig import get_paths, get_python_version, get_scheme_names
 from urllib.parse import urlparse
@@ -30,14 +31,6 @@ from pipenv.utils.processes import subprocess_run
 from pipenv.utils.shell import make_posix, temp_environ
 from pipenv.vendor.pythonfinder.utils import is_in_path
 
-try:
-    # this is only in Python3.8 and later
-    from functools import cached_property
-except ImportError:
-    # eventually distlib will remove cached property when they drop Python3.7
-    from pipenv.patched.pip._vendor.distlib.util import cached_property
-
-
 if typing.TYPE_CHECKING:
     from types import ModuleType
     from typing import ContextManager, Generator
